Release Notes
=============

Here you can see the full list of changes between python-socialite versions.
Versions are in form of *headline.major.minor* numbers.
Backwards-compatible changes increment the minor version number only.

Version 0.1.4
-------------

Released: 2021-02-07

-   Cleanup docs
-   Fix google login


Version 0.1.3
-------------

Released: 2020-05-10

-   Setup Google Authentication
-   Setup Linting and unit tests
-   Setup Github Actions
